@@ -29,13 +29,13 @@
 #' == 'multivar'. See \code{multivar-match} and \code{build_multivar_settings}.
 #' @param filter function or numeric. Filters a merged data1-data2 dataset. If a
 #'   function, should take in a data.frame (data1 and data2 merged by name1 and
-#'   name2) and spit out a trimmed verion of the data.frame (fewer rows). Think
+#'   name2) and spit out a trimmed version of the data.frame (fewer rows). Think
 #'   of this function as applying other conditions to matches, other than a
 #'   match by name. The first argument of filter should be the data.frame. If
 #'   numeric, will drop all observations with a matchscore lower than or equal
 #'   to filter.
 #' @param filter.args list. Arguments passed to filter, if a function
-#' @param evaluate Function to evalute merge_plus output.
+#' @param evaluate Function to evaluate merge_plus output.
 #' @param evaluate.args list. Arguments passed to evaluate
 #' @param allow.cartesian whether or not to allow many-many matches, see data.table::merge()
 #' @return list with matches, filtered matches (if applicable), data1 and data2
@@ -223,7 +223,7 @@ merge_plus <- function(data1, data2, by = NULL, by.x = NULL, by.y = NULL,
           matches[, c(variable_score) := fifelse(get(variable_x) == substr(get(variable_y), 1, nchar(get(variable_x))), 1, 0)]
         }
         if (score_type_i == "difference") {
-          matches[, c(variable_score) := scales::rescale(get(variable_x) - get(variable_y))]
+          matches[, c(variable_score) := scales::rescale(-abs(get(variable_x) - get(variable_y)))]
         }
         if (score_type_i == "ratio") {
           matches[, c(variable_score) := scales::rescale(get(variable_x) / get(variable_y))]
